pub struct SilenceRange {
pub start_us: i64,
pub end_us: i64,
pub channel: Option<usize>,
}Expand description
A detected silent region, in microseconds. channel is the 1-based channel
number in mono mode, or None for combined detection.
Fields
start_us: i64end_us: i64channel: Option<usize>Trait Implementations
Sourceimpl Clone for SilenceRange
impl Clone for SilenceRange
Sourcefn clone(&self) -> SilenceRange
fn clone(&self) -> SilenceRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SilenceRange
Sourceimpl Debug for SilenceRange
impl Debug for SilenceRange
Sourceimpl PartialEq for SilenceRange
impl PartialEq for SilenceRange
Sourcefn eq(&self, other: &SilenceRange) -> bool
fn eq(&self, other: &SilenceRange) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SilenceRange