#[non_exhaustive]pub enum DecodingError {
OutOfMemory,
InvalidArgument,
IOError,
Timeout,
PipeError,
BadFileDescriptor,
NotImplemented,
OperationNotPermitted,
TryAgain,
UnknownError(i32),
}Expand description
FFmpeg-level errors during decoding, carried by
DecodingOperationError.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OutOfMemory
Memory allocation failed (AVERROR(ENOMEM)).
InvalidArgument
FFmpeg rejected an argument as invalid (AVERROR(EINVAL)).
IOError
A low-level I/O error occurred (AVERROR(EIO)).
Timeout
The operation timed out (AVERROR(ETIMEDOUT)).
PipeError
The stream or data connection was broken (AVERROR(EPIPE)).
BadFileDescriptor
An invalid file descriptor was used (AVERROR(EBADF)).
NotImplemented
The functionality or format is not supported by the linked FFmpeg
build (AVERROR(ENOSYS)).
OperationNotPermitted
The operation was not permitted (AVERROR(EPERM)).
TryAgain
The decoder is temporarily unable to accept or produce data
(AVERROR(EAGAIN)).
UnknownError(i32)
Any other failure; the payload is the raw FFmpeg error code.