#[non_exhaustive]pub enum DemuxingOperationError {
ReadFrameError(DemuxingError),
PacketRefError(DemuxingError),
SeekFileError(DemuxingError),
ThreadExited,
}Expand description
Errors from the demuxer stage while reading packets from an input.
Variants carrying a DemuxingError embed the mapped FFmpeg error.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ReadFrameError(DemuxingError)
Returned when reading the next packet from the input fails
(av_read_frame).
PacketRefError(DemuxingError)
Returned when creating an additional reference to a demuxed packet
fails (av_packet_ref).
SeekFileError(DemuxingError)
Returned when seeking in the input fails (avformat_seek_file).
ThreadExited
Returned when spawning the demuxer thread fails, so demuxing never started.